==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/cy_GB.js <==
OC.L10N.register(
    "files",
    {
    "Could not move %s - File with this name already exists" : "Methwyd symud %s - Mae ffeil gyda'r enw hwn eisoes yn bodoli",
    "Could not move %s" : "Methwyd symud %s",
    "No file was uploaded. Unknown error" : "Ni lwythwyd ffeil i fyny. Gwall anhysbys.",
    "There is no error, the file uploaded with success" : "Does dim gwall, llwythodd y ffeil i fyny'n llwyddiannus",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Mae'r ffeil lwythwyd i fyny'n fwy na chyfarwyddeb upload_max_filesize yn php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Mae'r ffeil lwythwyd i fyny'n fwy na chyfarwyddeb MAX_FILE_SIZE bennwyd yn y ffurflen HTML",
    "The uploaded file was only partially uploaded" : "Dim ond yn rhannol y llwythwyd y ffeil i fyny",
    "No file was uploaded" : "Ni lwythwyd ffeil i fyny",
    "Missing a temporary folder" : "Plygell dros dro yn eisiau",
    "Failed to write to disk" : "Methwyd ysgrifennu i'r ddisg",
    "Not enough storage available" : "Dim digon o le storio ar gael",
    "Invalid directory." : "Cyfeiriadur annilys.",
    "Files" : "Ffeiliau",
    "Home" : "Cartref",
    "Close" : "Cau",
    "Upload cancelled." : "Diddymwyd llwytho i fyny.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Mae ffeiliau'n cael eu llwytho i fyny. Bydd gadael y dudalen hon nawr yn diddymu'r broses.",
    "Actions" : "Gweithredoedd",
    "Download" : "Llwytho i lawr",
    "Rename" : "Ailenwi",
    "Delete" : "Dileu",
    "Details" : "Manylion",
    "Pending" : "I ddod",
    "Error" : "Gwall",
    "{new_name} already exists" : "{new_name} yn bodoli'n barod",
    "Name" : "Enw",
    "Size" : "Maint",
    "Modified" : "Addaswyd",
    "New" : "Newydd",
    "File name cannot be empty." : "Does dim hawl cael enw ffeil gwag.",
    "Your storage is full, files can not be updated or synced anymore!" : "Mae eich storfa'n llawn, ni ellir diweddaru a chydweddu ffeiliau mwyach!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Mae eich storfa bron a bod yn llawn ({usedSpacePercent}%)",
    "Upload" : "Llwytho i fyny",
    "Text file" : "Ffeil destun",
    "Folder" : "Plygell",
    "File handling" : "Trafod ffeiliau",
    "Maximum upload size" : "Maint mwyaf llwytho i fyny",
    "max. possible: " : "mwyaf. posib:",
    "Save" : "Cadw",
    "Settings" : "Gosodiadau",
    "Cancel upload" : "Diddymu llwytho i fyny",
    "Upload too large" : "Maint llwytho i fyny'n rhy fawr",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Mae'r ffeiliau rydych yn ceisio llwytho i fyny'n fwy na maint mwyaf llwytho ffeiliau i fyny ar y gweinydd hwn.",
    "Files are being scanned, please wait." : "Arhoswch, mae ffeiliau'n cael eu sganio.",
    "Upload cancelled." : "Diddymwyd llwytho i fyny."
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/cy_GB.js <==
OC.L10N.register(
    "files",
    {
    "No file was uploaded. Unknown error" : "Ni lwythwyd ffeil i fyny. Gwall anhysbys.",
    "There is no error, the file uploaded with success" : "Does dim gwall, llwythodd y ffeil i fyny'n llwyddiannus",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Mae'r ffeil lwythwyd i fyny'n fwy na chyfarwyddeb upload_max_filesize yn php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Mae'r ffeil lwythwyd i fyny'n fwy na chyfarwyddeb MAX_FILE_SIZE bennwyd yn y ffurflen HTML",
    "The uploaded file was only partially uploaded" : "Dim ond yn rhannol y llwythwyd y ffeil i fyny",
    "No file was uploaded" : "Ni lwythwyd ffeil i fyny",
    "Missing a temporary folder" : "Plygell dros dro yn eisiau",
    "Failed to write to disk" : "Methwyd ysgrifennu i'r ddisg",
    "Not enough storage available" : "Dim digon o le storio ar gael",
    "Invalid directory." : "Cyfeiriadur annilys.",
    "Files" : "Ffeiliau",
    "Home" : "Cartref",
    "Close" : "Cau",
    "Upload cancelled." : "Diddymwyd llwytho i fyny.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Mae ffeiliau'n cael eu llwytho i fyny. Bydd gadael y dudalen hon nawr yn diddymu'r broses.",
    "Actions" : "Gweithredoedd",
    "Download" : "Llwytho i lawr",
    "Rename" : "Ailenwi",
    "Delete" : "Dileu",
    "Unshare" : "Dad-rannu",
    "Details" : "Manylion",
    "Pending" : "I ddod",
    "Name" : "Enw",
    "Size" : "Maint",
    "Modified" : "Addaswyd",
    "New" : "Newydd",
    "File name cannot be empty." : "Does dim hawl cael enw ffeil gwag.",
    "Your storage is full, files can not be updated or synced anymore!" : "Mae eich storfa'n llawn, ni ellir diweddaru a chydweddu ffeiliau mwyach!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Mae eich storfa bron a bod yn llawn ({usedSpacePercent}%)",
    "Folder" : "Plygell",
    "Upload" : "Llwytho i fyny",
    "File handling" : "Trafod ffeiliau",
    "Maximum upload size" : "Maint mwyaf llwytho i fyny",
    "max. possible: " : "mwyaf. posib:",
    "Save" : "Cadw",
    "Settings" : "Gosodiadau",
    "Cancel upload" : "Diddymu llwytho i fyny",
    "Upload too large" : "Maint llwytho i fyny'n rhy fawr",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Mae'r ffeiliau rydych yn ceisio llwytho i fyny'n fwy na maint mwyaf llwytho ffeiliau i fyny ar y gweinydd hwn.",
    "Text file" : "Ffeil destun"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
